==> ansys_mechanical_stubs-0.1.1.tar.gz: ansys_mechanical_stubs-0.1.1/src/ansys/mechanical/stubs/v242/Ansys/Mechanical/DataModel/ConstructionLines/Edges/__init__.py <==
"""Edges subpackage."""
import typing

class StraightLineEdge(object):
    """
    
                Representation of a straight line edge between to edge vertices.
            
    """

    @property
    def Length(self) -> typing.Optional["Ansys.Core.Units.Quantity"]:
        """
        Length property.
        """
        return None

    @property
    def EndPoint(self) -> typing.Optional["Ansys.Mechanical.DataModel.ConstructionLines.Point"]:
        """
        
                A Point representing the end vertex of the edge.
            
        """
        return None

    @property
    def StartPoint(self) -> typing.Optional["Ansys.Mechanical.DataModel.ConstructionLines.Point"]:
        """
        
                A Point representing the start vertex of an edge.
            
        """
        return None

    @property
    def ObjectId(self) -> typing.Optional["System.UInt32"]:
        """
        
                Get the ID of the represented entity.
            
        """
        return None

    @property
    def IsRepresentation(self) -> typing.Optional["System.Boolean"]:
        """
        
                Check to see if there is a valid entity that this instance represents.
            
        """
        return None


class IEdge(object):
    """
    
                Interface for edges created by ConstructionLine.
            
    """

    @property
    def Length(self) -> typing.Optional["Ansys.Core.Units.Quantity"]:
        """
        
                Get the length of this edge.
            
        """
        return None

==> ansys_mechanical_stubs-0.1.2.tar.gz: ansys_mechanical_stubs-0.1.2/src/ansys/mechanical/stubs/v242/Ansys/Mechanical/DataModel/ConstructionLines/Edges/__init__.py <==
"""Edges module."""
import typing

class StraightLineEdge(object):
    """
    
                Representation of a straight line edge between to edge vertices.
            
    """

    @property
    def Length(self) -> typing.Optional["Ansys.Core.Units.Quantity"]:
        """
        Length property.
        """
        return None

    @property
    def EndPoint(self) -> typing.Optional["Ansys.Mechanical.DataModel.ConstructionLines.Point"]:
        """
        
                A Point representing the end vertex of the edge.
            
        """
        return None

    @property
    def StartPoint(self) -> typing.Optional["Ansys.Mechanical.DataModel.ConstructionLines.Point"]:
        """
        
                A Point representing the start vertex of an edge.
            
        """
        return None

    @property
    def ObjectId(self) -> typing.Optional[int]:
        """
        
                Get the ID of the represented entity.
            
        """
        return None

    @property
    def IsRepresentation(self) -> typing.Optional[bool]:
        """
        
                Check to see if there is a valid entity that this instance represents.
            
        """
        return None


class IEdge(object):
    """
    
                Interface for edges created by ConstructionLine.
            
    """

    @property
    def Length(self) -> typing.Optional["Ansys.Core.Units.Quantity"]:
        """
        
                Get the length of this edge.
            
        """
        return None
